# Projeto Integrado - Trabalho Final

CNN Trained to predict brazilian beers

## Run project

```
source automation/build.sh
```

## Excluir os diretorios e arquivos criados

```
source automation/destroy.sh
```